@@ -11,7 +11,7 @@ init()
 # import Keys
 from selenium.webdriver.common.keys import Keys
 
-from .check import get_installed_chrome_path
+
 from .clean import Clean
 from .utils import Util
 
@@ -32,6 +32,30 @@ class Driver:
             ])
         return user_agent
 
+    def driver_navigator(self, driver):
+        if driver.execute_script("return navigator.webdriver"):
+            driver.execute_cdp_cmd(
+                    "Page.addScriptToEvaluateOnNewDocument",
+                    {
+                        "source": """
+
+                                Object.defineProperty(window, 'navigator', {
+                                    value: new Proxy(navigator, {
+                                    has: (target, key) => (key === 'webdriver' ? false : key in target),
+                                    get: (target, key) =>
+                                        key === 'webdriver'
+                                        ? undefined
+                                        : typeof target[key] === 'function'
+                                        ? target[key].bind(target)
+                                        : target[key]
+                                    })
+                                });
+                                    
+                                                            
+                        """
+                    },
+                )
+
     def open_new_cmd_and_run_command(self, profile_path="", port=9222, default_profile=False):
         """
         This function opens a new cmd window and runs the command
@@ -59,34 +83,34 @@ class Driver:
                 command = f'{google} --remote-debugging-port={port} --user-data-dir="{profile_path}"'
             os.system(f'gnome-terminal -- bash -c "{command}"')
 
-    def create_driver(self, headless=False, profile_path="", mute=False, debugging=False, default_profile=False, debug_port=9222):
+    def create_driver(self, headless=False, profile_path="", mute=False, debugging=False, default_profile=False, debug_port=9222, control_existing_instance=False):
+        from .check import get_installed_chrome_path
         path = get_installed_chrome_path()
+        os.chmod(path, 755)
         if not path:
             clean.remove_signature_in_javascript()
         if path is not None:
             options = webdriver.ChromeOptions()
             options.headless = headless
+            options.add_argument("--start-maximized")
+            options.add_argument("--lang=en-US")
             if profile_path:
                 options.add_argument(r"--user-data-dir=%s" % profile_path)
             if debugging:
-                self.open_new_cmd_and_run_command(profile_path=profile_path, port=debug_port, default_profile=default_profile)
+                if not control_existing_instance:
+                    self.open_new_cmd_and_run_command(profile_path=profile_path, port=debug_port, default_profile=default_profile)
                 options.add_experimental_option("debuggerAddress", f"127.0.0.1:{debug_port}")
             else:
                 options.add_experimental_option("excludeSwitches", ["enable-automation", "enable-logging"])
-                options.add_argument("--start-maximized")
                 options.add_argument("--log-level=3")
                 options.add_experimental_option('useAutomationExtension', False)
-                options.add_experimental_option(
-                    'prefs', {'intl.accept_languages': 'en_US,en'})
                 options.add_argument(f"user-agent={self.generate_user_agent()}")
                 if mute:
                     options.add_argument("--mute-audio")
                     options.add_argument('--no-sandbox')
-                options.add_argument('--disable-dev-shm-usage')
-                options.add_argument('--disable-features=UserAgentClientHint')
-                prefs = {"profile.default_content_setting_values.notifications" : 2}
-                options.add_experimental_option("prefs",prefs)
-                webdriver.DesiredCapabilities.CHROME['loggingPrefs'] = {'driver': 'OFF', 'server': 'OFF', 'browser': 'OFF'}
+                options.add_argument("start-maximized")
+                options.add_experimental_option("excludeSwitches", ["enable-automation"])
+                options.add_argument("--disable-blink-features=AutomationControlled")
             try:
                 driver = webdriver.Chrome(executable_path=path, options=options)
             except TypeError:
@@ -94,6 +118,7 @@ class Driver:
             except Exception as error:
                 sys.exit(colored("[-] ", "red")+f" {error}")
             else:
+                self.driver_navigator(driver)
                 driver.get("https://selmi.tech")
                 return driver
         else:
